"""Auto-generated file, do not edit by hand. AE metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AE = PhoneMetadata(id='AE', country_code=971, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{8}', possible_length=(9,)),
    uan=PhoneNumberDesc(national_number_pattern='600\\d{6}', example_number='600123456', possible_length=(9,)))
